# CoreDNS version in Kubernetes

This document records the CoreDNS version that was installed by kubeadm with each version of Kubernetes since v1.9. It also lists any CoreDNS feature deprecations between Kubernetes releases. This table should not be read as a recommendation for what version of CoreDNS to currently use per each Kubernetes release, especially for older k8s releases in this table.


| Kubernetes Version |      CoreDNS version installed by kubeadm      |  Changes in CoreDNS from previous release to Kubernetes |
|:------------------:|:-------------------------:|:----------|
|       v1.24        |  [v1.8.6](https://github.com/coredns/coredns/releases/tag/v1.8.6) |  |
|       v1.23        |  [v1.8.6](https://github.com/coredns/coredns/releases/tag/v1.8.6) | https://github.com/coredns/coredns/blob/master/notes/coredns-1.8.5.md <br>https://github.com/coredns/coredns/blob/master/notes/coredns-1.8.6.md |
|       v1.22        |  [v1.8.4](https://github.com/coredns/coredns/releases/tag/v1.8.4) | https://github.com/coredns/coredns/blob/master/notes/coredns-1.8.1.md <br>https://github.com/coredns/coredns/blob/master/notes/coredns-1.8.2.md <br>https://github.com/coredns/coredns/blob/master/notes/coredns-1.8.3.md <br>https://github.com/coredns/coredns/blob/master/notes/coredns-1.8.4.md <br><br> ***---NOTE---*** CoreDNS must be granted list and watch access to EndpointSlices |
|       v1.21        |  [v1.8.0](https://github.com/coredns/coredns/releases/tag/v1.8.0) | https://github.com/coredns/coredns/blob/master/notes/coredns-1.7.1.md <br>https://github.com/coredns/coredns/blob/master/notes/coredns-1.8.0.md <br><br> ***---DEPRECATIONS---***  <br><br> <ul> <li>The `transfer` option in the _kubernetes_ plugin has been removed. Zone transfers can be enabled with the new _transfer_ plugin.</li> </ul> |
|       v1.20        |  [v1.7.0](https://github.com/coredns/coredns/releases/tag/v1.7.0) |  |
|       v1.19        |  [v1.7.0](https://github.com/coredns/coredns/releases/tag/v1.7.0) | https://github.com/coredns/coredns/blob/master/notes/coredns-1.6.9.md <br>https://github.com/coredns/coredns/blob/master/notes/coredns-1.7.0.md <br><br> ***---DEPRECATIONS---***  <br><br> <ul> <li>The federation plugin (which allows for v1 Kubernetes federation) has been removed.</li> <li> Many Prometheus metrics names have changed. More details in https://coredns.io/2020/06/15/coredns-1.7.0-release/#metric-changes </li> </ul> |
|       v1.18        |  [v1.6.7](https://github.com/coredns/coredns/releases/tag/v1.6.7) | https://github.com/coredns/coredns/blob/master/notes/coredns-1.6.6.md <br> https://github.com/coredns/coredns/blob/master/notes/coredns-1.6.7.md <br><br> ***---DEPRECATIONS---***  <br><br> <ul> <li>None</li> </ul> |
|       v1.17        |  [v1.6.5](https://github.com/coredns/coredns/releases/tag/v1.6.5) | https://github.com/coredns/coredns/blob/master/notes/coredns-1.6.3.md <br> https://github.com/coredns/coredns/blob/master/notes/coredns-1.6.4.md <br> https://github.com/coredns/coredns/blob/master/notes/coredns-1.6.5.md <br><br> ***---DEPRECATIONS---***  <br><br> <ul> <li>None</li> </ul> |
|       v1.16        |  [v1.6.2](https://coredns.io/2019/08/13/coredns-1.6.2-release/)                   | `health` plugin will revert back to report process level health without plugin status. A new ready plugin will make sure plugins have at least completed their startup sequence. <br><br> kubernetes fixes the logging now that kubernetes’ client lib switched to klog from glog. <br><br> The ready plugin was added that signals a plugin is ready to receive queries. First user is the kubernetes plugin. <br><br> plugin/kubernetes: Don’t do a zone transfer for NS requests <br><br> ***---DEPRECATIONS---***  <br><br> <ul> <li> The proxy will be moved to an external repository and as such be deprecated from the default set of plugin; use the forward as a replacement. </li> <li> the kubernetes plugin removes the resyncperiod option.</li></ul>|
|   v1.14 & v1.15    |  [v1.3.1](https://coredns.io/2019/01/13/coredns-1.3.1-release/)                   | TTL is also applied to negative responses (NXDOMAIN, etc). <br> <br> k8s_external a new plugin that allows external zones to point to Kubernetes in-cluster services. <br><br>kubernetes now checks if a zone transfer is allowed. Also allow a TTL of 0 to avoid caching in the cache plugin. <br><br> ***---DEPRECATIONS---*** <br><br> <ul><li>None</li></ul>|
|       v1.13        |  [v1.2.6](https://coredns.io/2018/11/05/coredns-1.2.6-release/)                   | Support for using a kubeconfig file, including various auth providers (Azure not supported due to a compilation issue with that code).<br><br>`loop` plugin fixes a bug when dealing with a failing upstream.   <br><br> ***---DEPRECATIONS---*** <br><br> <ul><li>None</li></ul>|
|       v1.12        |  [v1.2.2](https://coredns.io/2018/08/29/coredns-1.2.2-release/)                   | Makes the default cache size smaller.<br><br> A new plugin called loop was added. When starting up it detects resolver loops and stops the process if one is detected. <br><br> The auto plugin now works better with Kubernetes Configmaps. <br><br> ***---DEPRECATIONS---***  <br><br> <ul> <li> The etcd plugin now supports etcd version 3 (only!). It was impossible to support v2 and v3 at the same time (even as separate plugins); so we decided to drop v2 support. </li> <li>The reverse plugin has been removed, but we allow it still in the configuration.</li></ul>
|       v1.11        |  [v1.1.3](https://coredns.io/2018/05/24/coredns-1.1.3-release/)                   | kubernetes has a small fix for apex queries.<br><br>kubernetes adds option to ignore services without ready endpoints.<br><br>cache fixes the critical spoof vulnerability.<br><br>A new plugin was added: reload, which watches for changes in your Corefile and then automatically will reload the process. <br><br> ***---DEPRECATIONS---*** <br><br> <ul><li>None</li></ul>
|       v1.10        |  [v1.0.6](https://coredns.io/2018/02/21/coredns-1.0.6-release/)                   | A plugin called `forward` has been included in CoreDNS, this was, up until now, an external plugin.<br><br>We now support zone transfers in the kubernetes plugin.<br><br> ***Fixes a vulnerability in the underlying DNS library, CVE-2017-15133.*** <br><br>kubernetes, adds a fix for pod insecure look ups for non-IP addresses. <br><br> ***---DEPRECATIONS---*** <br><br> <ul><li>The startup and shutdown plugin are deprecated (but working and included) in this release in favor of the on plugin. If you use them, this is the moment to move to on. <br><br> </li></ul>
|       v1.09        |  [v1.0.1](https://coredns.io/2017/12/11/coredns-1.0.1-release/)                   | The v1.0.1 was the first version of CoreDNS to be shipped with Kubernetes. |
